==> 0.0.1.tar.gz: lib/code_services/services/network_service.dart <==
import 'dart:io';

import 'package:code_id_flutter/code_interfaces/services/i_network_service.dart';
import 'package:code_id_flutter/code_interfaces/value/network_error.dart';

import 'package:connectivity_plus/connectivity_plus.dart';

import 'package:dio/dio.dart';
import 'package:flutter/material.dart';
import 'package:fpdart/fpdart.dart';

class NetworkService implements INetworkService {
  final Dio dio;
  final Connectivity connectivity;

  NetworkService({
    required this.dio,
    required this.connectivity,
  });

  @override
  Future<Either<NetworkError, dynamic>> getHttp({
    required String path,
    String? parameter,
    Map<String, dynamic>? queryParameter,
    Map<String, dynamic>? header,
    bool useAuth = true,
    Function(int, int)? onReceiveProgress,
  }) async {
    final connectivityResult = await connectivity.checkConnectivity();
    if (connectivityResult != ConnectivityResult.none) {
      try {
        final Map<String, dynamic> headers = {
          'content-type': ContentType.json.mimeType,
          'accept': ContentType.json.mimeType
        };

        if (header != null) {
          headers.addAll(header);
        }
        dio.options.headers = headers;

        final Response response = await dio.get(
          '$path${parameter ?? ""}',
          queryParameters: queryParameter,
          onReceiveProgress: onReceiveProgress,
        );
        return right(response.data);
      } on DioError catch (e) {
        debugPrint('================ERROR==================');
        debugPrint('${e.type.toString()}');
        switch (e.type) {
          case DioErrorType.connectTimeout:
            return left(NetworkError.timeout());
          case DioErrorType.other:
            return left(NetworkError.other(error: e.response!.data));
          default:
            return left(NetworkError.serverError(
                statusCode: e.response!.statusCode,
                statusMessage: e.response!.statusMessage));
        }
      }
    } else {
      return left(NetworkError.noInternet());
    }
  }

  @override
  Future<Either<NetworkError, dynamic>> postHttp({
    required String path,
    String? parameter,
    Map<String, dynamic>? queryParameter,
    dynamic content,
    String? contentType,
    Map<String, dynamic>? header,
    bool useAuth = true,
    Function(int, int)? onSendProgress,
    Function(int, int)? onReceiveProgress,
  }) async {
    final connectivityResult = await connectivity.checkConnectivity();
    if (connectivityResult != ConnectivityResult.none) {
      try {
        // await baseStorage.openBox(StorageConstants.base);
        final Map<String, dynamic> headers = {
          'content-type': ContentType.json.mimeType,
          'Accept': ContentType.json.mimeType,
        };
        if (header != null) {
          headers.addAll(header);
        }
        // if (useAuth) {
        //   final Map<String, dynamic>? security = await baseStorage.getData();
        //   if (security != null) {
        //     headers.addAll({'Authorization': 'Bearer ${security["token"]}'});
        //   }
        // }

        dio.options.headers = headers;
        // await baseStorage.close();

        final Response response = await dio.post(
          '$path${parameter ?? ""}',
          queryParameters: queryParameter,
          data: content,
          onSendProgress: onSendProgress,
          onReceiveProgress: onReceiveProgress,
        );
        return right(response.data);
      } on DioError catch (e) {
        debugPrint('================ERROR==================');
        debugPrint('${e.type.toString()}');
        switch (e.type) {
          case DioErrorType.connectTimeout:
            return left(NetworkError.timeout());
          case DioErrorType.other:
            return left(NetworkError.other(error: e.response!.data));
          default:
            return left(NetworkError.serverError(
                statusCode: e.response!.statusCode,
                statusMessage: e.response!.statusMessage));
        }
      }
    } else {
      return left(NetworkError.noInternet());
    }
  }

  @override
  Future<Either<NetworkError, dynamic>> putHttp({
    required String path,
    String? parameter,
    Map<String, dynamic>? queryParameter,
    Map<String, dynamic>? content,
    String? contentType,
    Map<String, dynamic>? header,
    bool useAuth = true,
    Function(int, int)? onSendProgress,
    Function(int, int)? onReceiveProgress,
  }) async {
    final connectivityResult = await connectivity.checkConnectivity();
    if (connectivityResult != ConnectivityResult.none) {
      try {
        // await baseStorage.openBox(StorageConstants.base);
        final Map<String, dynamic> headers = {
          'content-type': ContentType.json.mimeType,
          'Accept': ContentType.json.mimeType,
        };
        if (header != null) {
          headers.addAll(header);
        }

        dio.options.headers = headers;
        final Response response = await dio.put(
          '$path${parameter ?? ""}',
          queryParameters: queryParameter,
          data: content,
          onReceiveProgress: onReceiveProgress,
          onSendProgress: onSendProgress,
        );
        return right(response.data);
      } on DioError catch (e) {
        debugPrint('================ERROR==================');
        debugPrint('${e.type.toString()}');
        switch (e.type) {
          case DioErrorType.connectTimeout:
            return left(NetworkError.timeout());
          case DioErrorType.other:
            return left(NetworkError.other(error: e.response!.data));
          default:
            return left(NetworkError.serverError(
                statusCode: e.response!.statusCode,
                statusMessage: e.response!.statusMessage));
        }
      }
    } else {
      return left(NetworkError.noInternet());
    }
  }

  @override
  Future<Either<NetworkError, dynamic>> download({
    required String url,
    required String downloadPath,
    Map<String, dynamic>? queryParameter,
    Map<String, dynamic>? header,
    bool useAuth = true,
    Function(int, int)? onReceiveProgress,
  }) async {
    final connectivityResult = await connectivity.checkConnectivity();
    if (connectivityResult != ConnectivityResult.none) {
      try {
        // await baseStorage.openBox(StorageConstants.base);
        final Map<String, dynamic> headers = {
          'Accept': ContentType.binary.mimeType,
        };
        final savedDir = Directory(downloadPath);
        final bool hasExisted = await savedDir.exists();
        //print(hasExisted);
        if (!hasExisted) {
          await savedDir.create(recursive: true);
          //print('directory created');
        }
        dio.options.headers = headers;
        // await baseStorage.close();
        final Response response = await dio.download(url, downloadPath,
            onReceiveProgress: onReceiveProgress);
        return right(response.data);
      } on DioError catch (e) {
        debugPrint('================ERROR==================');
        debugPrint('${e.type.toString()}');
        switch (e.type) {
          case DioErrorType.connectTimeout:
            return left(NetworkError.timeout());
          case DioErrorType.other:
            return left(NetworkError.other(error: e.response!.data));
          default:
            return left(NetworkError.serverError(
                statusCode: e.response!.statusCode,
                statusMessage: e.response!.statusMessage));
        }
      }
    } else {
      return left(NetworkError.noInternet());
    }
  }
}

==> 0.0.3.tar.gz: lib/code_services/services/network_service.dart <==
import 'dart:io';

import 'package:code_id_flutter/code_interfaces/services/i_network_service.dart';
import 'package:code_id_flutter/code_interfaces/value/network_error.dart';

import 'package:connectivity_plus/connectivity_plus.dart';

import 'package:dio/dio.dart';
import 'package:flutter/material.dart';
import 'package:fpdart/fpdart.dart';

class NetworkService implements INetworkService {
  final Dio dio;
  final Connectivity connectivity;

  NetworkService({
    required this.dio,
    required this.connectivity,
  });

  @override
  Future<Either<NetworkError, dynamic>> getHttp({
    required String path,
    String? parameter,
    Map<String, dynamic>? queryParameter,
    Map<String, dynamic>? header,
    bool useAuth = true,
    Function(int, int)? onReceiveProgress,
  }) async {
    final connectivityResult = await connectivity.checkConnectivity();
    if (connectivityResult != ConnectivityResult.none) {
      try {
        final Map<String, dynamic> headers = {
          'content-type': ContentType.json.mimeType,
          'accept': ContentType.json.mimeType
        };

        if (header != null) {
          headers.addAll(header);
        }
        dio.options.headers = headers;

        final Response response = await dio.get(
          '$path${parameter ?? ""}',
          queryParameters: queryParameter,
          onReceiveProgress: onReceiveProgress,
        );
        return right(response.data);
      } on DioError catch (e) {
        debugPrint('================ERROR==================');
        debugPrint('${e.type.toString()}');
        switch (e.type) {
          case DioErrorType.connectTimeout:
            return left(NetworkError.timeout());
          case DioErrorType.other:
            return left(NetworkError.other(error: e.response!.data));
          default:
            return left(NetworkError.serverError(response: e.response));
        }
      }
    } else {
      return left(NetworkError.noInternet());
    }
  }

  @override
  Future<Either<NetworkError, dynamic>> postHttp({
    required String path,
    String? parameter,
    Map<String, dynamic>? queryParameter,
    dynamic content,
    String? contentType,
    Map<String, dynamic>? header,
    bool useAuth = true,
    Function(int, int)? onSendProgress,
    Function(int, int)? onReceiveProgress,
  }) async {
    final connectivityResult = await connectivity.checkConnectivity();
    if (connectivityResult != ConnectivityResult.none) {
      try {
        // await baseStorage.openBox(StorageConstants.base);
        final Map<String, dynamic> headers = {
          'content-type': ContentType.json.mimeType,
          'Accept': ContentType.json.mimeType,
        };
        if (header != null) {
          headers.addAll(header);
        }
        // if (useAuth) {
        //   final Map<String, dynamic>? security = await baseStorage.getData();
        //   if (security != null) {
        //     headers.addAll({'Authorization': 'Bearer ${security["token"]}'});
        //   }
        // }

        dio.options.headers = headers;
        // await baseStorage.close();

        final Response response = await dio.post(
          '$path${parameter ?? ""}',
          queryParameters: queryParameter,
          data: content,
          onSendProgress: onSendProgress,
          onReceiveProgress: onReceiveProgress,
        );
        return right(response.data);
      } on DioError catch (e) {
        debugPrint('================ERROR==================');
        debugPrint('${e.type.toString()}');
        switch (e.type) {
          case DioErrorType.connectTimeout:
            return left(NetworkError.timeout());
          case DioErrorType.other:
            return left(NetworkError.other(error: e.response!.data));
          default:
            return left(NetworkError.serverError(response: e.response));
        }
      }
    } else {
      return left(NetworkError.noInternet());
    }
  }

  @override
  Future<Either<NetworkError, dynamic>> putHttp({
    required String path,
    String? parameter,
    Map<String, dynamic>? queryParameter,
    Map<String, dynamic>? content,
    String? contentType,
    Map<String, dynamic>? header,
    bool useAuth = true,
    Function(int, int)? onSendProgress,
    Function(int, int)? onReceiveProgress,
  }) async {
    final connectivityResult = await connectivity.checkConnectivity();
    if (connectivityResult != ConnectivityResult.none) {
      try {
        // await baseStorage.openBox(StorageConstants.base);
        final Map<String, dynamic> headers = {
          'content-type': ContentType.json.mimeType,
          'Accept': ContentType.json.mimeType,
        };
        if (header != null) {
          headers.addAll(header);
        }

        dio.options.headers = headers;
        final Response response = await dio.put(
          '$path${parameter ?? ""}',
          queryParameters: queryParameter,
          data: content,
          onReceiveProgress: onReceiveProgress,
          onSendProgress: onSendProgress,
        );
        return right(response.data);
      } on DioError catch (e) {
        debugPrint('================ERROR==================');
        debugPrint('${e.type.toString()}');

        switch (e.type) {
          case DioErrorType.connectTimeout:
            return left(NetworkError.timeout());
          case DioErrorType.other:
            return left(NetworkError.other(error: e.response!.data));
          default:
            return left(NetworkError.serverError(response: e.response));
        }
      }
    } else {
      return left(NetworkError.noInternet());
    }
  }

  @override
  Future<Either<NetworkError, dynamic>> download({
    required String url,
    required String downloadPath,
    Map<String, dynamic>? queryParameter,
    Map<String, dynamic>? header,
    bool useAuth = true,
    Function(int, int)? onReceiveProgress,
  }) async {
    final connectivityResult = await connectivity.checkConnectivity();
    if (connectivityResult != ConnectivityResult.none) {
      try {
        // await baseStorage.openBox(StorageConstants.base);
        final Map<String, dynamic> headers = {
          'Accept': ContentType.binary.mimeType,
        };
        final savedDir = Directory(downloadPath);
        final bool hasExisted = await savedDir.exists();
        //print(hasExisted);
        if (!hasExisted) {
          await savedDir.create(recursive: true);
          //print('directory created');
        }
        dio.options.headers = headers;
        // await baseStorage.close();
        final Response response = await dio.download(url, downloadPath,
            onReceiveProgress: onReceiveProgress);
        return right(response.data);
      } on DioError catch (e) {
        debugPrint('================ERROR==================');
        debugPrint('${e.type.toString()}');
        switch (e.type) {
          case DioErrorType.connectTimeout:
            return left(NetworkError.timeout());
          case DioErrorType.other:
            return left(NetworkError.other(error: e.response!.data));
          default:
            return left(NetworkError.serverError(response: e.response));
        }
      }
    } else {
      return left(NetworkError.noInternet());
    }
  }
}
